import base64
import requests
import os

client_id = base64.b64encode("{0}:{1}".format(os.environ['TCKEY'], os.environ['TCSEC']))

# Trimble Identity 
authority = "https://identity.trimble.com"

auth_uri = "{0}/token?{1}&{2}&{3}".format(authority,
                                          "grant_type=client_credentials",
                                          "scope=openid",
                                          "tenantDomain=trimble.com")

def step1_id_token(client_id):
    r= requests.post(auth_uri,
                     headers = {"Content-Type": "application/x-www-form-urlencoded",
                                "Authorization":"Basic {0}".format(client_id),
                                "Accept":"application/json"})
    r.raise_for_status()
    return r.json()['id_token']



# Trimble Connect Authorization
tc_pod = "https://app.connect.trimble.com"

tc_api = "tc/api/2.0"

token_uri = "{0}/{1}/{2}".format(tc_pod, tc_api, 'auth/token')


def step2_tc_token(id_token):
    r = requests.post(token_uri,
                      headers = {"Content-Type":"application/json"},
                      json = {"jwt":id_token})
    r.raise_for_status()
    return r.json()['token']


# Core Procedures
def projects(headers):
    r = requests.get("{0}/{1}/projects".format(tc_pod, tc_api),
                     headers = headers)
    r.raise_for_status()
    return r.json()


# Business Logic
def workflow(client_id):
    token = step2_tc_token(step1_id_token(client_id))
    headers = {"Authorization": "Bearer {0}".format(token)}
    for p in projects(headers):
        print "{0},{1}".format(p['name'], p['id'])
